==> aliyun-python-sdk-elasticsearch-3.0.26.tar.gz: aliyun-python-sdk-elasticsearch-3.0.26/aliyunsdkelasticsearch/request/v20170613/ListDictInformationRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkelasticsearch.endpoint import endpoint_data

class ListDictInformationRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'elasticsearch', '2017-06-13', 'ListDictInformation','elasticsearch')
		self.set_uri_pattern('/openapi/instances/[InstanceId]/dict/_info')
		self.set_method('GET')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_InstanceId(self):
		return self.get_path_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_path_param('InstanceId',InstanceId)

	def get_analyzerType(self):
		return self.get_query_params().get('analyzerType')

	def set_analyzerType(self,analyzerType):
		self.add_query_param('analyzerType',analyzerType)

	def get_bucketName(self):
		return self.get_query_params().get('bucketName')

	def set_bucketName(self,bucketName):
		self.add_query_param('bucketName',bucketName)

	def get_key(self):
		return self.get_query_params().get('key')

	def set_key(self,key):
		self.add_query_param('key',key)

==> aliyun-python-sdk-elasticsearch-3.1.1.tar.gz: aliyun-python-sdk-elasticsearch-3.1.1/aliyunsdkelasticsearch/request/v20170613/ListDictInformationRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RoaRequest
from aliyunsdkelasticsearch.endpoint import endpoint_data

class ListDictInformationRequest(RoaRequest):

	def __init__(self):
		RoaRequest.__init__(self, 'elasticsearch', '2017-06-13', 'ListDictInformation','elasticsearch')
		self.set_uri_pattern('/openapi/instances/[InstanceId]/dict/_info')
		self.set_method('GET')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_InstanceId(self): # string
		return self.get_path_params().get('InstanceId')

	def set_InstanceId(self, InstanceId):  # string
		self.add_path_param('InstanceId', InstanceId)
	def get_analyzerType(self): # string
		return self.get_query_params().get('analyzerType')

	def set_analyzerType(self, analyzerType):  # string
		self.add_query_param('analyzerType', analyzerType)
	def get_bucketName(self): # string
		return self.get_query_params().get('bucketName')

	def set_bucketName(self, bucketName):  # string
		self.add_query_param('bucketName', bucketName)
	def get_key(self): # string
		return self.get_query_params().get('key')

	def set_key(self, key):  # string
		self.add_query_param('key', key)
